@@ -61,35 +61,75 @@
 ##    Last Modified: 28/04/1999
 ##
 
-use strict;
-
 package OpenCA::Configuration;
 
-$OpenCA::Configuration::VERSION = '1.5.3';
+use strict;
+use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);
+
+require Exporter;
+require AutoLoader;
+
+@ISA = qw(Exporter AutoLoader);
+# Items to export into callers namespace by default. Note: do not export
+# names by default without a very good reason. Use EXPORT_OK instead.
+# Do not simply export all your public functions/methods/constants.
+@EXPORT = qw(
+	
+);
+$VERSION = '1.2';
+
 
 # Preloaded methods go here.
 
+# Autoload methods go after =cut, and are processed by the autosplit program.
+
+1;
+__END__
+# Below is the stub of documentation for your module. You better edit it!
+
+=head1 NAME
+
+OpenCA::Configuration - Perl extension for blah blah blah
+
+=head1 SYNOPSIS
+
+  use OpenCA::Configuration;
+  blah blah blah
+
+=head1 DESCRIPTION
+
+Stub documentation for OpenCA::Configuration was created by h2xs. It looks like the
+author of the extension was negligent enough to leave the stub
+unedited.
+
+Blah blah blah.
+
+=head1 AUTHOR
+
+A. U. Thor, a.u.thor@a.galaxy.far.far.away
+
+=head1 SEE ALSO
+
+perl(1).
+
+=cut
+
 ## Define Error Messages for the Configuration Manager Errors
-my %params = {
-	cnfLines => undef,
-	cnfDB => undef,
-};
+my $cgiManager  = 'Massimiliano Pala <madwolf@comune.modena.it>';
+my $configDim   = 0;
+
+my @configLines = ();
+my @configDB    = ();
+my @errorCodes  = { '100', 'Configuration File Not Found',
+		    '101', 'Keyword error.'}; 
 
 ## Create an instance of the Class
 sub new {
-	my $that = shift;
-	my $class = ref($that) || $that;
+	my $self = {};
+	bless $self;
 
-	my $self = {
-		%params,
-	};
-
-	bless $self, $class;
-
-	my @keys = @_ ;
-	my $fileName = $keys[0];
-
-	if( defined $fileName and $fileName ne "" ) {
+	$fileName = $keys[1];
+	if( "$fileName" ne "" ) {
 		my $ret = $self->loadCfg ( $fileName );
 		return undef if ( not $ret );
 	}
@@ -100,53 +140,30 @@ sub new {
 ## Configuration Manager Functions
 sub loadCfg {
 	my $self = shift;
-	my @keys = @_ ; 
+	my $ret = 0;
+	my @keys; 
+	@keys = @_;
 
-	my $temp;
-	my $temp2;
-	my @configLines;
-	my $sameLine;
+	$fileName = $keys[0];
 
-	my $fileName = $keys[0];
-
-	$sameLine = 0;
-	$temp2 = "";
 	open( FD, "$fileName" ) || return undef;
 	while( $temp = <FD> ) {
-		if( $temp =~ /\\\n$/ ) {
-			$temp =~ s/\\\n$//;
-			$temp2 .= $temp;
-			$sameLine = 1;
-		} else {
-			if( $sameLine == 1 ) {
-				$temp2 .= $temp;
-				$temp = $temp2;
-				$sameLine = 0;
-				$temp2 = "";
-			}
-
-			$sameLine = 0;
-			push ( @configLines, $temp);
-		}
+		@configLines = ( @configLines, $temp );
 	}
 	close(FD);
 
-	if( $self->parsecfg( @configLines ) ) {
-		$self->{cnfLines} = [ @configLines ];
-		return 1;
-	} else {
-		return 0;
-	}
+	$ret = $self->parsecfg( @configLines );
+	return $ret;
 }
 
 ## Parsing Function
 sub parsecfg {
 	my $self = shift;
-	my @keys = @_;
-
-	my @configDB = ();
+	my @keys;
 	my $num = -1;
-	my $line;
+	@keys = @_;
+
+	@configDB = ();
 	
 	foreach $line (@keys) {
 		my $paramName;
@@ -158,11 +175,9 @@ sub parsecfg {
 
 		## Trial line and discard Comments
 		chop($line);
-		## next if ($line =~ /\#.*/)||($line eq "")||($line =~ /HASH.*/);
-		next if ($line =~ /\#.*/)||($line =~ /^\s*[\n\r]*$/)||($line =~ /HASH.*/);
+		next if ($line =~ /\#.*/)||($line eq "")||($line =~ /HASH.*/);
 		$line =~ s/#.*//;
 		$line =~ s/^[\s]*//;
-		$line =~ s/(\r|\n)//g;
 
 		## Get the Parameter Name
 		( $paramName ) = 
@@ -181,33 +196,37 @@ sub parsecfg {
 			$line =~ s/^[\s]*//;
 
 			if ( $line =~ /^\"/ ) {
-			 	( $param ) = ( $line =~ /^\"(.*?)\"/ );
-			 	$line =~ s/^\".*?\"//;
+				( $param ) = ( $line =~ /^\"([^\"]*)/ );
 			} else {
-			 	( $param ) = ( $line =~ /^([\S]+)/ );
-			 	$line =~ s/^([\S]+)//;
+				( $param ) = ( $line =~ /^([\S]+)/ );
 			};
 
 			@values = ( @values, $param );
 			
+			$param =~ s/\$/\\\$/g;
+			$line =~ s/$param//;
+			$line =~ s/""//;
+
 		}
 
 		## Get the parameter set up
-		my $par = { NAME=>$paramName,
+		$par = { NAME=>$paramName,
 		 	 LINE_NUMBER=>$num,
 		 	 VALUES=>[ @values ] };
 
-		push ( @configDB, $par);
+		push @configDB, $par;
 	}
 
-	$self->{cnfDB} = [ @configDB ];
-	return 1;
+	return @configDB;
 }
 
 ## Get Single Parameter
 sub getParam {
 	my $self = shift;
-	my @keys = @_;
+	my %ret = {};
+	my @keys;
+	my @par = ();
+	@keys = @_;
 
 	return $self->getNextParam( NAME=>$keys[0],
 		LINE_NUMBER=>-1 );
@@ -216,16 +235,17 @@ sub getParam {
 ## Get next Parameter	 
 sub getNextParam {
 	my $self = shift;
-        my $k = { @_ };
-	my $par;
+        my %k = @_;
+	my %par = {};
+	
+	return undef unless ( $#_ > 0 );
 
-	return if( not ( $k->{NAME} ) );
-
-	foreach $par ( @{$self->{cnfDB}} ) {
+	foreach $par ( @configDB ) {
 		my $tmp = $par->{NAME};
+		$tmp =~ s/^$k{NAME}//i;
 
-		if( (lc( $tmp ) eq lc($k->{NAME})) and
-			( $par->{LINE_NUMBER} > $k->{LINE_NUMBER})  ) {
+		if ( ( "$tmp" eq ""  ) &&
+				( $par->{LINE_NUMBER} > $k{LINE_NUMBER})  ) {
 			return $par;
 		};
 	};
@@ -235,10 +255,11 @@ sub getNextParam {
 
 sub checkParam {
 	my $self = shift;
-	my $k = { @_ };
-	my ( $par, $pnum );
+	my %k = @_;
+	my %par = {};
+	my $pnum;
 
-	return unless ( exists $k->{NAME} );
+	return unless ( $#_ > 0 );
 
 	$par = $self->getParam( $k->{NAME} );
 	return unless ( not ( keys %$par ));
@@ -258,12 +279,12 @@ sub checkParam {
 
 sub checkConfig {
 	my $self = shift;
-	my @keys = @_;
-	my ( $ret, $par );
+	my @parameters = @_;
+	my $ret;
 
-	foreach $par ( @keys ) {
+	foreach $par ( @parameters ) {
 		$ret = $self->ceckParam( $par );
-		return if ( not $ret);
+		return if ( $ret == -1 );
 	}
 
 	return 0;
@@ -272,7 +293,7 @@ sub checkConfig {
 sub getVersion {
 	my $self = shift;
 
-	return $OpenCA::Configuration::VERSION;
+	return $VERSION;
 }
 
-1;
+___END___;
